/*
 * Copyright (c) 2005 - 2007, Tranql project contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.tranql.connector.mysql;

import com.mysql.jdbc.jdbc2.optional.MysqlConnectionPoolDataSource;
import org.tranql.connector.jdbc.AbstractLocalDataSourceMCF;
import org.tranql.connector.jdbc.AbstractPooledConnectionDataSourceMCF;

import java.sql.SQLException;

/**
 * ManagedConnectionFactory for connecting to a MySQL database with local (non-XA) transactions.
 *
 * @version $Revision: 712 $ $Date: 2010-04-27 17:44:37 -0700 (Tue, 27 Apr 2010) $
 */
public class LocalMCF extends AbstractPooledConnectionDataSourceMCF<MysqlConnectionPoolDataSource> {
    private String password;

    /**
     * Default constructor for a MySQL Local DataSource.
     *
     */
    public LocalMCF() {
        super(new MysqlConnectionPoolDataSource(), new MysqlExceptionSorter());
    }

    public void setDatabaseName(String dbname) {
        connectionPoolDataSource.setDatabaseName(dbname);
    }

    public String getDatabaseName() {
        return connectionPoolDataSource.getDatabaseName();
    }

    public void setPassword(String pwd) {
        this.password = pwd;
        connectionPoolDataSource.setPassword(pwd);
    }

    public String getPassword() {
        return password;
    }

    public void setPortNumber(Integer pn) {
        connectionPoolDataSource.setPortNumber(pn == null ? 0 : pn.intValue());
    }

    public Integer getPortNumber() {
        return new Integer(connectionPoolDataSource.getPortNumber());
    }

    public void setServerName(String sn) {
        connectionPoolDataSource.setServerName(sn);
    }

    public String getServerName() {
        return connectionPoolDataSource.getServerName();
    }

    public void setUserName(String user) {
        connectionPoolDataSource.setUser(user);
    }

    public String getUserName() {
        return connectionPoolDataSource.getUser();
    }

    //new

    public boolean getAllowLoadLocalInfile() {
        return connectionPoolDataSource.getAllowLoadLocalInfile();
    }

    public boolean getAllowMultiQueries() {
        return connectionPoolDataSource.getAllowMultiQueries();
    }

    public boolean getAllowNanAndInf() {
        return connectionPoolDataSource.getAllowNanAndInf();
    }

    public boolean getAllowUrlInLocalInfile() {
        return connectionPoolDataSource.getAllowUrlInLocalInfile();
    }

    public boolean getAlwaysSendSetIsolation() {
        return connectionPoolDataSource.getAlwaysSendSetIsolation();
    }

    public boolean getAutoDeserialize() {
        return connectionPoolDataSource.getAutoDeserialize();
    }

    public boolean getAutoGenerateTestcaseScript() {
        return connectionPoolDataSource.getAutoGenerateTestcaseScript();
    }

    public boolean getAutoReconnectForPools() {
        return connectionPoolDataSource.getAutoReconnectForPools();
    }

    public int getBlobSendChunkSize() {
        return connectionPoolDataSource.getBlobSendChunkSize();
    }

    public boolean getCacheCallableStatements() {
        return connectionPoolDataSource.getCacheCallableStatements();
    }

    public boolean getCachePreparedStatements() {
        return connectionPoolDataSource.getCachePreparedStatements();
    }

    public boolean getCacheResultSetMetadata() {
        return connectionPoolDataSource.getCacheResultSetMetadata();
    }

    public boolean getCacheServerConfiguration() {
        return connectionPoolDataSource.getCacheServerConfiguration();
    }

    public int getCallableStatementCacheSize() {
        return connectionPoolDataSource.getCallableStatementCacheSize();
    }

    public boolean getCapitalizeTypeNames() {
        return connectionPoolDataSource.getCapitalizeTypeNames();
    }

    public String getCharacterSetResults() {
        return connectionPoolDataSource.getCharacterSetResults();
    }

    public boolean getClobberStreamingResults() {
        return connectionPoolDataSource.getClobberStreamingResults();
    }

    public String getClobCharacterEncoding() {
        return connectionPoolDataSource.getClobCharacterEncoding();
    }

    public String getConnectionCollation() {
        return connectionPoolDataSource.getConnectionCollation();
    }

    public int getConnectTimeout() {
        return connectionPoolDataSource.getConnectTimeout();
    }

    public boolean getContinueBatchOnError() {
        return connectionPoolDataSource.getContinueBatchOnError();
    }

    public boolean getCreateDatabaseIfNotExist() {
        return connectionPoolDataSource.getCreateDatabaseIfNotExist();
    }

    public int getDefaultFetchSize() {
        return connectionPoolDataSource.getDefaultFetchSize();
    }

    public boolean getDontTrackOpenResources() {
        return connectionPoolDataSource.getDontTrackOpenResources();
    }

    public boolean getDumpQueriesOnException() {
        return connectionPoolDataSource.getDumpQueriesOnException();
    }

    public boolean getDynamicCalendars() {
        return connectionPoolDataSource.getDynamicCalendars();
    }

    public boolean getElideSetAutoCommits() {
        return connectionPoolDataSource.getElideSetAutoCommits();
    }

    public boolean getEmptyStringsConvertToZero() {
        return connectionPoolDataSource.getEmptyStringsConvertToZero();
    }

    public boolean getEmulateLocators() {
        return connectionPoolDataSource.getEmulateLocators();
    }

    public boolean getEmulateUnsupportedPstmts() {
        return connectionPoolDataSource.getEmulateUnsupportedPstmts();
    }

    public boolean getEnablePacketDebug() {
        return connectionPoolDataSource.getEnablePacketDebug();
    }

    public String getEncoding() {
        return connectionPoolDataSource.getEncoding();
    }

    public boolean getExplainSlowQueries() {
        return connectionPoolDataSource.getExplainSlowQueries();
    }

    public boolean getFailOverReadOnly() {
        return connectionPoolDataSource.getFailOverReadOnly();
    }

    public boolean getGatherPerformanceMetrics() {
        return connectionPoolDataSource.getGatherPerformanceMetrics();
    }

    public boolean getHoldResultsOpenOverStatementClose() {
        return connectionPoolDataSource.getHoldResultsOpenOverStatementClose();
    }

    public boolean getIgnoreNonTxTables() {
        return connectionPoolDataSource.getIgnoreNonTxTables();
    }

    public int getInitialTimeout() {
        return connectionPoolDataSource.getInitialTimeout();
    }

    public boolean getInteractiveClient() {
        return connectionPoolDataSource.getInteractiveClient();
    }

    public boolean getIsInteractiveClient() {
        return connectionPoolDataSource.getIsInteractiveClient();
    }

    public boolean getJdbcCompliantTruncation() {
        return connectionPoolDataSource.getJdbcCompliantTruncation();
    }

    public int getLocatorFetchBufferSize() {
        return connectionPoolDataSource.getLocatorFetchBufferSize();
    }

    public boolean getLogSlowQueries() {
        return connectionPoolDataSource.getLogSlowQueries();
    }

    public boolean getMaintainTimeStats() {
        return connectionPoolDataSource.getMaintainTimeStats();
    }

    public int getMaxQuerySizeToLog() {
        return connectionPoolDataSource.getMaxQuerySizeToLog();
    }

    public int getMaxReconnects() {
        return connectionPoolDataSource.getMaxReconnects();
    }

    public int getMaxRows() {
        return connectionPoolDataSource.getMaxRows();
    }

    public int getMetadataCacheSize() {
        return connectionPoolDataSource.getMetadataCacheSize();
    }

    public boolean getNoDatetimeStringSync() {
        return connectionPoolDataSource.getNoDatetimeStringSync();
    }

    public boolean getNullCatalogMeansCurrent() {
        return connectionPoolDataSource.getNullCatalogMeansCurrent();
    }

    public boolean getNullNamePatternMatchesAll() {
        return connectionPoolDataSource.getNullNamePatternMatchesAll();
    }

    public int getPacketDebugBufferSize() {
        return connectionPoolDataSource.getPacketDebugBufferSize();
    }

    public boolean getParanoid() {
        return connectionPoolDataSource.getParanoid();
    }

    public boolean getPedantic() {
        return connectionPoolDataSource.getPedantic();
    }

    public int getPreparedStatementCacheSize() {
        return connectionPoolDataSource.getPreparedStatementCacheSize();
    }

    public int getPreparedStatementCacheSqlLimit() {
        return connectionPoolDataSource.getPreparedStatementCacheSqlLimit();
    }

    public boolean getProfileSql() {
        return connectionPoolDataSource.getProfileSql();
    }

    public boolean getProfileSQL() {
        return connectionPoolDataSource.getProfileSQL();
    }

    public String getPropertiesTransform() {
        return connectionPoolDataSource.getPropertiesTransform();
    }

    public int getQueriesBeforeRetryMaster() {
        return connectionPoolDataSource.getQueriesBeforeRetryMaster();
    }

    public boolean getReconnectAtTxEnd() {
        return connectionPoolDataSource.getReconnectAtTxEnd();
    }

    public boolean getRelaxAutoCommit() {
        return connectionPoolDataSource.getRelaxAutoCommit();
    }

    public int getReportMetricsIntervalMillis() {
        return connectionPoolDataSource.getReportMetricsIntervalMillis();
    }

    public boolean getRequireSSL() {
        return connectionPoolDataSource.getRequireSSL();
    }

    public boolean getRetainStatementAfterResultSetClose() {
        return connectionPoolDataSource.getRetainStatementAfterResultSetClose();
    }

    public boolean getRollbackOnPooledClose() {
        return connectionPoolDataSource.getRollbackOnPooledClose();
    }

    public boolean getRoundRobinLoadBalance() {
        return connectionPoolDataSource.getRoundRobinLoadBalance();
    }

    public boolean getRunningCTS13() {
        return connectionPoolDataSource.getRunningCTS13();
    }

    public int getSecondsBeforeRetryMaster() {
        return connectionPoolDataSource.getSecondsBeforeRetryMaster();
    }

    public String getServerTimezone() {
        return connectionPoolDataSource.getServerTimezone();
    }

    public String getSessionVariables() {
        return connectionPoolDataSource.getSessionVariables();
    }

    public int getSlowQueryThresholdMillis() {
        return connectionPoolDataSource.getSlowQueryThresholdMillis();
    }

    public String getSocketFactoryClassName() {
        return connectionPoolDataSource.getSocketFactoryClassName();
    }

    public int getSocketTimeout() {
        return connectionPoolDataSource.getSocketTimeout();
    }

    public boolean getStrictFloatingPoint() {
        return connectionPoolDataSource.getStrictFloatingPoint();
    }

    public boolean getStrictUpdates() {
        return connectionPoolDataSource.getStrictUpdates();
    }

    public boolean getTinyInt1isBit() {
        return connectionPoolDataSource.getTinyInt1isBit();
    }

    public boolean getTraceProtocol() {
        return connectionPoolDataSource.getTraceProtocol();
    }

    public boolean getTransformedBitIsBoolean() {
        return connectionPoolDataSource.getTransformedBitIsBoolean();
    }

    public boolean getUseCompression() {
        return connectionPoolDataSource.getUseCompression();
    }

    public boolean getUseFastIntParsing() {
        return connectionPoolDataSource.getUseFastIntParsing();
    }

    public boolean getUseHostsInPrivileges() {
        return connectionPoolDataSource.getUseHostsInPrivileges();
    }

    public boolean getUseInformationSchema() {
        return connectionPoolDataSource.getUseInformationSchema();
    }

    public boolean getUseLocalSessionState() {
        return connectionPoolDataSource.getUseLocalSessionState();
    }

    public boolean getUseOldUTF8Behavior() {
        return connectionPoolDataSource.getUseOldUTF8Behavior();
    }

    public boolean getUseOnlyServerErrorMessages() {
        return connectionPoolDataSource.getUseOnlyServerErrorMessages();
    }

    public boolean getUseReadAheadInput() {
        return connectionPoolDataSource.getUseReadAheadInput();
    }

    public boolean getUseServerPreparedStmts() {
        return connectionPoolDataSource.getUseServerPreparedStmts();
    }

    public boolean getUseSqlStateCodes() {
        return connectionPoolDataSource.getUseSqlStateCodes();
    }

    public boolean getUseSSL() {
        return connectionPoolDataSource.getUseSSL();
    }

    public boolean getUseStreamLengthsInPrepStmts() {
        return connectionPoolDataSource.getUseStreamLengthsInPrepStmts();
    }

    public boolean getUseTimezone() {
        return connectionPoolDataSource.getUseTimezone();
    }

    public boolean getUseUltraDevWorkAround() {
        return connectionPoolDataSource.getUseUltraDevWorkAround();
    }

    public boolean getUseUnbufferedInput() {
        return connectionPoolDataSource.getUseUnbufferedInput();
    }

    public boolean getUseUnicode() {
        return connectionPoolDataSource.getUseUnicode();
    }

    public boolean getUseUsageAdvisor() {
        return connectionPoolDataSource.getUseUsageAdvisor();
    }

    public boolean getYearIsDateType() {
        return connectionPoolDataSource.getYearIsDateType();
    }

    public String getZeroDateTimeBehavior() {
        return connectionPoolDataSource.getZeroDateTimeBehavior();
    }

    public void setAllowLoadLocalInfile(boolean property) {
        connectionPoolDataSource.setAllowLoadLocalInfile(property);
    }

    public void setAllowMultiQueries(boolean property) {
        connectionPoolDataSource.setAllowMultiQueries(property);
    }

    public void setAllowNanAndInf(boolean flag) {
        connectionPoolDataSource.setAllowNanAndInf(flag);
    }

    public void setAllowUrlInLocalInfile(boolean flag) {
        connectionPoolDataSource.setAllowUrlInLocalInfile(flag);
    }

    public void setAlwaysSendSetIsolation(boolean flag) {
        connectionPoolDataSource.setAlwaysSendSetIsolation(flag);
    }

    public void setAutoDeserialize(boolean flag) {
        connectionPoolDataSource.setAutoDeserialize(flag);
    }

    public void setAutoGenerateTestcaseScript(boolean flag) {
        connectionPoolDataSource.setAutoGenerateTestcaseScript(flag);
    }

    public void setAutoReconnect(boolean flag) {
        connectionPoolDataSource.setAutoReconnect(flag);
    }

    public void setAutoReconnectForConnectionPools(boolean property) {
        connectionPoolDataSource.setAutoReconnectForConnectionPools(property);
    }

    public void setAutoReconnectForPools(boolean flag) {
        connectionPoolDataSource.setAutoReconnectForPools(flag);
    }

    public void setBlobSendChunkSize(String value) throws SQLException {
        connectionPoolDataSource.setBlobSendChunkSize(value);
    }

    public void setCacheCallableStatements(boolean flag) {
        connectionPoolDataSource.setCacheCallableStatements(flag);
    }

    public void setCachePreparedStatements(boolean flag) {
        connectionPoolDataSource.setCachePreparedStatements(flag);
    }

    public void setCacheResultSetMetadata(boolean property) {
        connectionPoolDataSource.setCacheResultSetMetadata(property);
    }

    public void setCacheServerConfiguration(boolean flag) {
        connectionPoolDataSource.setCacheServerConfiguration(flag);
    }

    public void setCallableStatementCacheSize(int size) {
        connectionPoolDataSource.setCallableStatementCacheSize(size);
    }

    public void setCapitalizeDBMDTypes(boolean property) {
        connectionPoolDataSource.setCapitalizeDBMDTypes(property);
    }

    public void setCapitalizeTypeNames(boolean flag) {
        connectionPoolDataSource.setCapitalizeTypeNames(flag);
    }

    public void setCharacterEncoding(String encoding) {
        connectionPoolDataSource.setCharacterEncoding(encoding);
    }

    public void setCharacterSetResults(String characterSet) {
        connectionPoolDataSource.setCharacterSetResults(characterSet);
    }

    public void setClobberStreamingResults(boolean flag) {
        connectionPoolDataSource.setClobberStreamingResults(flag);
    }

    public void setClobCharacterEncoding(String encoding) {
        connectionPoolDataSource.setClobCharacterEncoding(encoding);
    }

    public void setConnectionCollation(String collation) {
        connectionPoolDataSource.setConnectionCollation(collation);
    }

    public void setConnectTimeout(int timeoutMs) {
        connectionPoolDataSource.setConnectTimeout(timeoutMs);
    }

    public void setContinueBatchOnError(boolean property) {
        connectionPoolDataSource.setContinueBatchOnError(property);
    }

    public void setCreateDatabaseIfNotExist(boolean flag) {
        connectionPoolDataSource.setCreateDatabaseIfNotExist(flag);
    }

    public void setDefaultFetchSize(int n) {
        connectionPoolDataSource.setDefaultFetchSize(n);
    }

    public void setDetectServerPreparedStmts(boolean property) {
        connectionPoolDataSource.setDetectServerPreparedStmts(property);
    }

    public void setDontTrackOpenResources(boolean flag) {
        connectionPoolDataSource.setDontTrackOpenResources(flag);
    }

    public void setDumpQueriesOnException(boolean flag) {
        connectionPoolDataSource.setDumpQueriesOnException(flag);
    }

    public void setDynamicCalendars(boolean flag) {
        connectionPoolDataSource.setDynamicCalendars(flag);
    }

    public void setElideSetAutoCommits(boolean flag) {
        connectionPoolDataSource.setElideSetAutoCommits(flag);
    }

    public void setEmptyStringsConvertToZero(boolean flag) {
        connectionPoolDataSource.setEmptyStringsConvertToZero(flag);
    }

    public void setEmulateLocators(boolean property) {
        connectionPoolDataSource.setEmulateLocators(property);
    }

    public void setEmulateUnsupportedPstmts(boolean flag) {
        connectionPoolDataSource.setEmulateUnsupportedPstmts(flag);
    }

    public void setEnablePacketDebug(boolean flag) {
        connectionPoolDataSource.setEnablePacketDebug(flag);
    }

    public void setEncoding(String property) {
        connectionPoolDataSource.setEncoding(property);
    }

    public void setExplainSlowQueries(boolean flag) {
        connectionPoolDataSource.setExplainSlowQueries(flag);
    }

    public void setFailOverReadOnly(boolean flag) {
        connectionPoolDataSource.setFailOverReadOnly(flag);
    }

    public void setGatherPerformanceMetrics(boolean flag) {
        connectionPoolDataSource.setGatherPerformanceMetrics(flag);
    }

    public void setHoldResultsOpenOverStatementClose(boolean flag) {
        connectionPoolDataSource.setHoldResultsOpenOverStatementClose(flag);
    }

    public void setIgnoreNonTxTables(boolean property) {
        connectionPoolDataSource.setIgnoreNonTxTables(property);
    }

    public void setInitialTimeout(int property) {
        connectionPoolDataSource.setInitialTimeout(property);
    }

    public void setIsInteractiveClient(boolean property) {
        connectionPoolDataSource.setIsInteractiveClient(property);
    }

    public void setJdbcCompliantTruncation(boolean flag) {
        connectionPoolDataSource.setJdbcCompliantTruncation(flag);
    }

    public void setLocatorFetchBufferSize(String value) throws SQLException {
        connectionPoolDataSource.setLocatorFetchBufferSize(value);
    }

    public void setLogSlowQueries(boolean flag) {
        connectionPoolDataSource.setLogSlowQueries(flag);
    }

    public void setMaintainTimeStats(boolean flag) {
        connectionPoolDataSource.setMaintainTimeStats(flag);
    }

    public void setMaxQuerySizeToLog(int sizeInBytes) {
        connectionPoolDataSource.setMaxQuerySizeToLog(sizeInBytes);
    }

    public void setMaxReconnects(int property) {
        connectionPoolDataSource.setMaxReconnects(property);
    }

    public void setMaxRows(int property) {
        connectionPoolDataSource.setMaxRows(property);
    }

    public void setMetadataCacheSize(int value) {
        connectionPoolDataSource.setMetadataCacheSize(value);
    }

    public void setNoDatetimeStringSync(boolean flag) {
        connectionPoolDataSource.setNoDatetimeStringSync(flag);
    }

    public void setNullCatalogMeansCurrent(boolean value) {
        connectionPoolDataSource.setNullCatalogMeansCurrent(value);
    }

    public void setNullNamePatternMatchesAll(boolean value) {
        connectionPoolDataSource.setNullNamePatternMatchesAll(value);
    }

    public void setPacketDebugBufferSize(int size) {
        connectionPoolDataSource.setPacketDebugBufferSize(size);
    }

    public void setParanoid(boolean property) {
        connectionPoolDataSource.setParanoid(property);
    }

    public void setPedantic(boolean property) {
        connectionPoolDataSource.setPedantic(property);
    }

    public void setPreparedStatementCacheSize(int cacheSize) {
        connectionPoolDataSource.setPreparedStatementCacheSize(cacheSize);
    }

    public void setPreparedStatementCacheSqlLimit(int cacheSqlLimit) {
        connectionPoolDataSource.setPreparedStatementCacheSqlLimit(cacheSqlLimit);
    }

    public void setProfileSql(boolean property) {
        connectionPoolDataSource.setProfileSql(property);
    }

    public void setProfileSQL(boolean flag) {
        connectionPoolDataSource.setProfileSQL(flag);
    }

    public void setPropertiesTransform(String value) {
        connectionPoolDataSource.setPropertiesTransform(value);
    }

    public void setQueriesBeforeRetryMaster(int property) {
        connectionPoolDataSource.setQueriesBeforeRetryMaster(property);
    }

    public void setReconnectAtTxEnd(boolean property) {
        connectionPoolDataSource.setReconnectAtTxEnd(property);
    }

    public void setRelaxAutoCommit(boolean property) {
        connectionPoolDataSource.setRelaxAutoCommit(property);
    }

    public void setReportMetricsIntervalMillis(int millis) {
        connectionPoolDataSource.setReportMetricsIntervalMillis(millis);
    }

    public void setRequireSSL(boolean property) {
        connectionPoolDataSource.setRequireSSL(property);
    }

    public void setRetainStatementAfterResultSetClose(boolean flag) {
        connectionPoolDataSource.setRetainStatementAfterResultSetClose(flag);
    }

    public void setRollbackOnPooledClose(boolean flag) {
        connectionPoolDataSource.setRollbackOnPooledClose(flag);
    }

    public void setRoundRobinLoadBalance(boolean flag) {
        connectionPoolDataSource.setRoundRobinLoadBalance(flag);
    }

    public void setRunningCTS13(boolean flag) {
        connectionPoolDataSource.setRunningCTS13(flag);
    }

    public void setSecondsBeforeRetryMaster(int property) {
        connectionPoolDataSource.setSecondsBeforeRetryMaster(property);
    }

    public void setServerTimezone(String property) {
        connectionPoolDataSource.setServerTimezone(property);
    }

    public void setSessionVariables(String variables) {
        connectionPoolDataSource.setSessionVariables(variables);
    }

    public void setSlowQueryThresholdMillis(int millis) {
        connectionPoolDataSource.setSlowQueryThresholdMillis(millis);
    }

    public void setSocketFactoryClassName(String property) {
        connectionPoolDataSource.setSocketFactoryClassName(property);
    }

    public void setSocketTimeout(int property) {
        connectionPoolDataSource.setSocketTimeout(property);
    }

    public void setStrictFloatingPoint(boolean property) {
        connectionPoolDataSource.setStrictFloatingPoint(property);
    }

    public void setStrictUpdates(boolean property) {
        connectionPoolDataSource.setStrictUpdates(property);
    }

    public void setTinyInt1isBit(boolean flag) {
        connectionPoolDataSource.setTinyInt1isBit(flag);
    }

    public void setTraceProtocol(boolean flag) {
        connectionPoolDataSource.setTraceProtocol(flag);
    }

    public void setTransformedBitIsBoolean(boolean flag) {
        connectionPoolDataSource.setTransformedBitIsBoolean(flag);
    }

    public void setUseCompression(boolean property) {
        connectionPoolDataSource.setUseCompression(property);
    }

    public void setUseFastIntParsing(boolean flag) {
        connectionPoolDataSource.setUseFastIntParsing(flag);
    }

    public void setUseHostsInPrivileges(boolean property) {
        connectionPoolDataSource.setUseHostsInPrivileges(property);
    }

    public void setUseInformationSchema(boolean flag) {
        connectionPoolDataSource.setUseInformationSchema(flag);
    }

    public void setUseLocalSessionState(boolean flag) {
        connectionPoolDataSource.setUseLocalSessionState(flag);
    }

    public void setUseOldUTF8Behavior(boolean flag) {
        connectionPoolDataSource.setUseOldUTF8Behavior(flag);
    }

    public void setUseOnlyServerErrorMessages(boolean flag) {
        connectionPoolDataSource.setUseOnlyServerErrorMessages(flag);
    }

    public void setUseReadAheadInput(boolean flag) {
        connectionPoolDataSource.setUseReadAheadInput(flag);
    }

    public void setUseServerPreparedStmts(boolean flag) {
        connectionPoolDataSource.setUseServerPreparedStmts(flag);
    }

    public void setUseSqlStateCodes(boolean flag) {
        connectionPoolDataSource.setUseSqlStateCodes(flag);
    }

    public void setUseSSL(boolean property) {
        connectionPoolDataSource.setUseSSL(property);
    }

    public void setUseStreamLengthsInPrepStmts(boolean property) {
        connectionPoolDataSource.setUseStreamLengthsInPrepStmts(property);
    }

    public void setUseTimezone(boolean property) {
        connectionPoolDataSource.setUseTimezone(property);
    }

    public void setUseUltraDevWorkAround(boolean property) {
        connectionPoolDataSource.setUseUltraDevWorkAround(property);
    }

    public void setUseUnbufferedInput(boolean flag) {
        connectionPoolDataSource.setUseUnbufferedInput(flag);
    }

    public void setUseUnicode(boolean flag) {
        connectionPoolDataSource.setUseUnicode(flag);
    }

    public void setUseUsageAdvisor(boolean useUsageAdvisorFlag) {
        connectionPoolDataSource.setUseUsageAdvisor(useUsageAdvisorFlag);
    }

    public void setYearIsDateType(boolean flag) {
        connectionPoolDataSource.setYearIsDateType(flag);
    }

    public void setZeroDateTimeBehavior(String behavior) {
        connectionPoolDataSource.setZeroDateTimeBehavior(behavior);
    }

    public boolean useUnbufferedInput() {
        return connectionPoolDataSource.useUnbufferedInput();
    }

    public boolean getUseCursorFetch() {
        return connectionPoolDataSource.getUseCursorFetch();
    }

    public void setUseCursorFetch(boolean flag) {
        connectionPoolDataSource.setUseCursorFetch(flag);
    }

    public boolean getOverrideSupportsIntegrityEnhancementFacility() {
        return connectionPoolDataSource.getOverrideSupportsIntegrityEnhancementFacility();
    }

    public void setOverrideSupportsIntegrityEnhancementFacility(boolean flag) {
        connectionPoolDataSource.setOverrideSupportsIntegrityEnhancementFacility(flag);
    }

    public boolean getNoTimezoneConversionForTimeType() {
        return connectionPoolDataSource.getNoTimezoneConversionForTimeType();
    }

    public void setNoTimezoneConversionForTimeType(boolean flag) {
        connectionPoolDataSource.setNoTimezoneConversionForTimeType(flag);
    }

    public boolean getUseJDBCCompliantTimezoneShift() {
        return connectionPoolDataSource.getUseJDBCCompliantTimezoneShift();
    }

    public void setUseJDBCCompliantTimezoneShift(boolean flag) {
        connectionPoolDataSource.setUseJDBCCompliantTimezoneShift(flag);
    }

    public boolean getAutoClosePStmtStreams() {
        return connectionPoolDataSource.getAutoClosePStmtStreams();
    }

    public void setAutoClosePStmtStreams(boolean flag) {
        connectionPoolDataSource.setAutoClosePStmtStreams(flag);
    }

    public boolean getProcessEscapeCodesForPrepStmts() {
        return connectionPoolDataSource.getProcessEscapeCodesForPrepStmts();
    }

    public void setProcessEscapeCodesForPrepStmts(boolean flag) {
        connectionPoolDataSource.setProcessEscapeCodesForPrepStmts(flag);
    }

    public boolean getUseGmtMillisForDatetimes() {
        return connectionPoolDataSource.getUseGmtMillisForDatetimes();
    }

    public void setUseGmtMillisForDatetimes(boolean flag) {
        connectionPoolDataSource.setUseGmtMillisForDatetimes(flag);
    }

    public boolean getDumpMetadataOnColumnNotFound() {
        return connectionPoolDataSource.getDumpMetadataOnColumnNotFound();
    }

    public void setDumpMetadataOnColumnNotFound(boolean flag) {
        connectionPoolDataSource.setDumpMetadataOnColumnNotFound(flag);
    }

    public String getResourceId() {
        return connectionPoolDataSource.getResourceId();
    }

    public void setResourceId(String resourceId) {
        connectionPoolDataSource.setResourceId(resourceId);
    }

    public boolean getRewriteBatchedStatements() {
        return connectionPoolDataSource.getRewriteBatchedStatements();
    }

    public void setRewriteBatchedStatements(boolean flag) {
        connectionPoolDataSource.setRewriteBatchedStatements(flag);
    }

    public boolean getJdbcCompliantTruncationForReads() {
        return connectionPoolDataSource.getJdbcCompliantTruncationForReads();
    }

    public void setJdbcCompliantTruncationForReads(boolean jdbcCompliantTruncationForReads) {
        connectionPoolDataSource.setJdbcCompliantTruncationForReads(jdbcCompliantTruncationForReads);
    }

    public boolean getUseJvmCharsetConverters() {
        return connectionPoolDataSource.getUseJvmCharsetConverters();
    }

    public void setUseJvmCharsetConverters(boolean flag) {
        connectionPoolDataSource.setUseJvmCharsetConverters(flag);
    }

    public boolean getPinGlobalTxToPhysicalConnection() {
        return connectionPoolDataSource.getPinGlobalTxToPhysicalConnection();
    }

    public void setPinGlobalTxToPhysicalConnection(boolean flag) {
        connectionPoolDataSource.setPinGlobalTxToPhysicalConnection(flag);
    }

    public void setGatherPerfMetrics(boolean flag) {
        connectionPoolDataSource.setGatherPerfMetrics(flag);
    }

    public boolean getGatherPerfMetrics() {
        return connectionPoolDataSource.getGatherPerfMetrics();
    }

    public void setUltraDevHack(boolean flag) {
        connectionPoolDataSource.setUltraDevHack(flag);
    }

    public boolean getUltraDevHack() {
        return connectionPoolDataSource.getUltraDevHack();
    }

    public void setInteractiveClient(boolean property) {
        connectionPoolDataSource.setInteractiveClient(property);
    }

    public void setSocketFactory(String name) {
        connectionPoolDataSource.setSocketFactory(name);
    }

    public String getSocketFactory() {
        return connectionPoolDataSource.getSocketFactory();
    }

    public void setUseServerPrepStmts(boolean flag) {
        connectionPoolDataSource.setUseServerPrepStmts(flag);
    }

    public boolean getUseServerPrepStmts() {
        return connectionPoolDataSource.getUseServerPrepStmts();
    }

    public void setCacheCallableStmts(boolean flag) {
        connectionPoolDataSource.setCacheCallableStmts(flag);
    }

    public boolean getCacheCallableStmts() {
        return connectionPoolDataSource.getCacheCallableStmts();
    }

    public void setCachePrepStmts(boolean flag) {
        connectionPoolDataSource.setCachePrepStmts(flag);
    }

    public boolean getCachePrepStmts() {
        return connectionPoolDataSource.getCachePrepStmts();
    }

    public void setCallableStmtCacheSize(int cacheSize) {
        connectionPoolDataSource.setCallableStmtCacheSize(cacheSize);
    }

    public int getCallableStmtCacheSize() {
        return connectionPoolDataSource.getCallableStmtCacheSize();
    }

    public void setPrepStmtCacheSize(int cacheSize) {
        connectionPoolDataSource.setPrepStmtCacheSize(cacheSize);
    }

    public int getPrepStmtCacheSize() {
        return connectionPoolDataSource.getPrepStmtCacheSize();
    }

    public void setPrepStmtCacheSqlLimit(int sqlLimit) {
        connectionPoolDataSource.setPrepStmtCacheSqlLimit(sqlLimit);
    }

    public int getPrepStmtCacheSqlLimit() {
        return connectionPoolDataSource.getPrepStmtCacheSqlLimit();
    }

    public boolean getNoAccessToProcedureBodies() {
        return connectionPoolDataSource.getNoAccessToProcedureBodies();
    }

    public void setNoAccessToProcedureBodies(boolean flag) {
        connectionPoolDataSource.setNoAccessToProcedureBodies(flag);
    }

    public boolean getUseOldAliasMetadataBehavior() {
        return connectionPoolDataSource.getUseOldAliasMetadataBehavior();
    }

    public void setUseOldAliasMetadataBehavior(boolean flag) {
        connectionPoolDataSource.setUseOldAliasMetadataBehavior(flag);
    }

    public boolean getUseSSPSCompatibleTimezoneShift() {
        return connectionPoolDataSource.getUseSSPSCompatibleTimezoneShift();
    }

    public void setUseSSPSCompatibleTimezoneShift(boolean flag) {
        connectionPoolDataSource.setUseSSPSCompatibleTimezoneShift(flag);
    }

    public boolean getTreatUtilDateAsTimestamp() {
        return connectionPoolDataSource.getTreatUtilDateAsTimestamp();
    }

    public void setTreatUtilDateAsTimestamp(boolean flag) {
        connectionPoolDataSource.setTreatUtilDateAsTimestamp(flag);
    }

    public boolean getUseFastDateParsing() {
        return connectionPoolDataSource.getUseFastDateParsing();
    }

    public void setUseFastDateParsing(boolean flag) {
        connectionPoolDataSource.setUseFastDateParsing(flag);
    }

    public String getLocalSocketAddress() {
        return connectionPoolDataSource.getLocalSocketAddress();
    }

    public void setLocalSocketAddress(String address) {
        connectionPoolDataSource.setLocalSocketAddress(address);
    }

    public void setUseConfigs(String configs) {
        connectionPoolDataSource.setUseConfigs(configs);
    }

    public String getUseConfigs() {
        return connectionPoolDataSource.getUseConfigs();
    }

    public boolean getGenerateSimpleParameterMetadata() {
        return connectionPoolDataSource.getGenerateSimpleParameterMetadata();
    }

    public void setGenerateSimpleParameterMetadata(boolean flag) {
        connectionPoolDataSource.setGenerateSimpleParameterMetadata(flag);
    }

    public boolean getLogXaCommands() {
        return connectionPoolDataSource.getLogXaCommands();
    }

    public void setLogXaCommands(boolean flag) {
        connectionPoolDataSource.setLogXaCommands(flag);
    }

    public int getResultSetSizeThreshold() {
        return connectionPoolDataSource.getResultSetSizeThreshold();
    }

    public void setResultSetSizeThreshold(int threshold) {
        connectionPoolDataSource.setResultSetSizeThreshold(threshold);
    }

    //end new

    /**
     * Equality is defined in terms of the serverName, portNumber and databaseName properties
     *
     */
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof LocalMCF) {
            MysqlConnectionPoolDataSource other = ((LocalMCF) obj).connectionPoolDataSource;
            return equals(connectionPoolDataSource.getServerName(), other.getServerName()) &&
                    connectionPoolDataSource.getPortNumber() == other.getPortNumber() &&
                    equals(connectionPoolDataSource.getDatabaseName(), other.getDatabaseName());
        } else {
            return false;
        }
    }

    private static boolean equals(String a, String b) {
        return a == b || a != null && a.equals(b);
    }

    public int hashCode() {
        return hashCode(connectionPoolDataSource.getServerName()) ^ connectionPoolDataSource.getPortNumber() ^ hashCode(connectionPoolDataSource.getDatabaseName());
    }

    private static int hashCode(String s) {
        return s == null ? 0 : s.hashCode();
    }

    public String toString() {
        return "LocalMCF[" + getDatabaseName() + ']';
    }
}
