/*
 * Copyright (c) 2005 - 2007, Tranql project contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.tranql.connector.mysql;

import com.mysql.jdbc.jdbc2.optional.MysqlXADataSource;
import org.tranql.connector.jdbc.AbstractXADataSourceMCF;

import java.sql.SQLException;

/**
 * ManagedConnectionFactory for connecting to a MySQL database with XA transactions.
 *
 * @version $Revision: 712 $ $Date: 2010-04-27 17:44:37 -0700 (Tue, 27 Apr 2010) $
 */
public class XAMCF extends AbstractXADataSourceMCF<MysqlXADataSource> {
    private String password;

    /**
     * Default constructor for an MySQL XA DataSource.
     *
     */
    public XAMCF() {
        super(new MysqlXADataSource(), new MysqlExceptionSorter());
    }

    public void setDatabaseName(String dbname) {
        xaDataSource.setDatabaseName(dbname);
    }

    public String getDatabaseName() {
        return xaDataSource.getDatabaseName();
    }

    public void setPassword(String pwd) {
        this.password = pwd;
        xaDataSource.setPassword(pwd);
    }

    public String getPassword() {
        return password;
    }

    public void setPortNumber(Integer pn) {
        xaDataSource.setPortNumber(pn == null ? 0 : pn.intValue());
    }

    public Integer getPortNumber() {
        return new Integer(xaDataSource.getPortNumber());
    }

    public void setServerName(String sn) {
        xaDataSource.setServerName(sn);
    }

    public String getServerName() {
        return xaDataSource.getServerName();
    }

    public void setUserName(String user) {
        xaDataSource.setUser(user);
    }

    public String getUserName() {
        return xaDataSource.getUser();
    }

    public boolean getAllowLoadLocalInfile() {
        return xaDataSource.getAllowLoadLocalInfile();
    }

    public boolean getAllowMultiQueries() {
        return xaDataSource.getAllowMultiQueries();
    }

    public boolean getAllowNanAndInf() {
        return xaDataSource.getAllowNanAndInf();
    }

    public boolean getAllowUrlInLocalInfile() {
        return xaDataSource.getAllowUrlInLocalInfile();
    }

    public boolean getAlwaysSendSetIsolation() {
        return xaDataSource.getAlwaysSendSetIsolation();
    }

    public boolean getAutoDeserialize() {
        return xaDataSource.getAutoDeserialize();
    }

    public boolean getAutoGenerateTestcaseScript() {
        return xaDataSource.getAutoGenerateTestcaseScript();
    }

    public boolean getAutoReconnectForPools() {
        return xaDataSource.getAutoReconnectForPools();
    }

    public int getBlobSendChunkSize() {
        return xaDataSource.getBlobSendChunkSize();
    }

    public boolean getCacheCallableStatements() {
        return xaDataSource.getCacheCallableStatements();
    }

    public boolean getCachePreparedStatements() {
        return xaDataSource.getCachePreparedStatements();
    }

    public boolean getCacheResultSetMetadata() {
        return xaDataSource.getCacheResultSetMetadata();
    }

    public boolean getCacheServerConfiguration() {
        return xaDataSource.getCacheServerConfiguration();
    }

    public int getCallableStatementCacheSize() {
        return xaDataSource.getCallableStatementCacheSize();
    }

    public boolean getCapitalizeTypeNames() {
        return xaDataSource.getCapitalizeTypeNames();
    }

    public String getCharacterSetResults() {
        return xaDataSource.getCharacterSetResults();
    }

    public boolean getClobberStreamingResults() {
        return xaDataSource.getClobberStreamingResults();
    }

    public String getClobCharacterEncoding() {
        return xaDataSource.getClobCharacterEncoding();
    }

    public String getConnectionCollation() {
        return xaDataSource.getConnectionCollation();
    }

    public int getConnectTimeout() {
        return xaDataSource.getConnectTimeout();
    }

    public boolean getContinueBatchOnError() {
        return xaDataSource.getContinueBatchOnError();
    }

    public boolean getCreateDatabaseIfNotExist() {
        return xaDataSource.getCreateDatabaseIfNotExist();
    }

    public int getDefaultFetchSize() {
        return xaDataSource.getDefaultFetchSize();
    }

    public boolean getDontTrackOpenResources() {
        return xaDataSource.getDontTrackOpenResources();
    }

    public boolean getDumpQueriesOnException() {
        return xaDataSource.getDumpQueriesOnException();
    }

    public boolean getDynamicCalendars() {
        return xaDataSource.getDynamicCalendars();
    }

    public boolean getElideSetAutoCommits() {
        return xaDataSource.getElideSetAutoCommits();
    }

    public boolean getEmptyStringsConvertToZero() {
        return xaDataSource.getEmptyStringsConvertToZero();
    }

    public boolean getEmulateLocators() {
        return xaDataSource.getEmulateLocators();
    }

    public boolean getEmulateUnsupportedPstmts() {
        return xaDataSource.getEmulateUnsupportedPstmts();
    }

    public boolean getEnablePacketDebug() {
        return xaDataSource.getEnablePacketDebug();
    }

    public String getEncoding() {
        return xaDataSource.getEncoding();
    }

    public boolean getExplainSlowQueries() {
        return xaDataSource.getExplainSlowQueries();
    }

    public boolean getFailOverReadOnly() {
        return xaDataSource.getFailOverReadOnly();
    }

    public boolean getGatherPerformanceMetrics() {
        return xaDataSource.getGatherPerformanceMetrics();
    }

    public boolean getHoldResultsOpenOverStatementClose() {
        return xaDataSource.getHoldResultsOpenOverStatementClose();
    }

    public boolean getIgnoreNonTxTables() {
        return xaDataSource.getIgnoreNonTxTables();
    }

    public int getInitialTimeout() {
        return xaDataSource.getInitialTimeout();
    }

    public boolean getInteractiveClient() {
        return xaDataSource.getInteractiveClient();
    }

    public boolean getIsInteractiveClient() {
        return xaDataSource.getIsInteractiveClient();
    }

    public boolean getJdbcCompliantTruncation() {
        return xaDataSource.getJdbcCompliantTruncation();
    }

    public int getLocatorFetchBufferSize() {
        return xaDataSource.getLocatorFetchBufferSize();
    }

    public boolean getLogSlowQueries() {
        return xaDataSource.getLogSlowQueries();
    }

    public boolean getMaintainTimeStats() {
        return xaDataSource.getMaintainTimeStats();
    }

    public int getMaxQuerySizeToLog() {
        return xaDataSource.getMaxQuerySizeToLog();
    }

    public int getMaxReconnects() {
        return xaDataSource.getMaxReconnects();
    }

    public int getMaxRows() {
        return xaDataSource.getMaxRows();
    }

    public int getMetadataCacheSize() {
        return xaDataSource.getMetadataCacheSize();
    }

    public boolean getNoDatetimeStringSync() {
        return xaDataSource.getNoDatetimeStringSync();
    }

    public boolean getNullCatalogMeansCurrent() {
        return xaDataSource.getNullCatalogMeansCurrent();
    }

    public boolean getNullNamePatternMatchesAll() {
        return xaDataSource.getNullNamePatternMatchesAll();
    }

    public int getPacketDebugBufferSize() {
        return xaDataSource.getPacketDebugBufferSize();
    }

    public boolean getParanoid() {
        return xaDataSource.getParanoid();
    }

    public boolean getPedantic() {
        return xaDataSource.getPedantic();
    }

    public int getPreparedStatementCacheSize() {
        return xaDataSource.getPreparedStatementCacheSize();
    }

    public int getPreparedStatementCacheSqlLimit() {
        return xaDataSource.getPreparedStatementCacheSqlLimit();
    }

    public boolean getProfileSql() {
        return xaDataSource.getProfileSql();
    }

    public boolean getProfileSQL() {
        return xaDataSource.getProfileSQL();
    }

    public String getPropertiesTransform() {
        return xaDataSource.getPropertiesTransform();
    }

    public int getQueriesBeforeRetryMaster() {
        return xaDataSource.getQueriesBeforeRetryMaster();
    }

    public boolean getReconnectAtTxEnd() {
        return xaDataSource.getReconnectAtTxEnd();
    }

    public boolean getRelaxAutoCommit() {
        return xaDataSource.getRelaxAutoCommit();
    }

    public int getReportMetricsIntervalMillis() {
        return xaDataSource.getReportMetricsIntervalMillis();
    }

    public boolean getRequireSSL() {
        return xaDataSource.getRequireSSL();
    }

    public boolean getRetainStatementAfterResultSetClose() {
        return xaDataSource.getRetainStatementAfterResultSetClose();
    }

    public boolean getRollbackOnPooledClose() {
        return xaDataSource.getRollbackOnPooledClose();
    }

    public boolean getRoundRobinLoadBalance() {
        return xaDataSource.getRoundRobinLoadBalance();
    }

    public boolean getRunningCTS13() {
        return xaDataSource.getRunningCTS13();
    }

    public int getSecondsBeforeRetryMaster() {
        return xaDataSource.getSecondsBeforeRetryMaster();
    }

    public String getServerTimezone() {
        return xaDataSource.getServerTimezone();
    }

    public String getSessionVariables() {
        return xaDataSource.getSessionVariables();
    }

    public int getSlowQueryThresholdMillis() {
        return xaDataSource.getSlowQueryThresholdMillis();
    }

    public String getSocketFactoryClassName() {
        return xaDataSource.getSocketFactoryClassName();
    }

    public int getSocketTimeout() {
        return xaDataSource.getSocketTimeout();
    }

    public boolean getStrictFloatingPoint() {
        return xaDataSource.getStrictFloatingPoint();
    }

    public boolean getStrictUpdates() {
        return xaDataSource.getStrictUpdates();
    }

    public boolean getTinyInt1isBit() {
        return xaDataSource.getTinyInt1isBit();
    }

    public boolean getTraceProtocol() {
        return xaDataSource.getTraceProtocol();
    }

    public boolean getTransformedBitIsBoolean() {
        return xaDataSource.getTransformedBitIsBoolean();
    }

    public boolean getUseCompression() {
        return xaDataSource.getUseCompression();
    }

    public boolean getUseFastIntParsing() {
        return xaDataSource.getUseFastIntParsing();
    }

    public boolean getUseHostsInPrivileges() {
        return xaDataSource.getUseHostsInPrivileges();
    }

    public boolean getUseInformationSchema() {
        return xaDataSource.getUseInformationSchema();
    }

    public boolean getUseLocalSessionState() {
        return xaDataSource.getUseLocalSessionState();
    }

    public boolean getUseOldUTF8Behavior() {
        return xaDataSource.getUseOldUTF8Behavior();
    }

    public boolean getUseOnlyServerErrorMessages() {
        return xaDataSource.getUseOnlyServerErrorMessages();
    }

    public boolean getUseReadAheadInput() {
        return xaDataSource.getUseReadAheadInput();
    }

    public boolean getUseServerPreparedStmts() {
        return xaDataSource.getUseServerPreparedStmts();
    }

    public boolean getUseSqlStateCodes() {
        return xaDataSource.getUseSqlStateCodes();
    }

    public boolean getUseSSL() {
        return xaDataSource.getUseSSL();
    }

    public boolean getUseStreamLengthsInPrepStmts() {
        return xaDataSource.getUseStreamLengthsInPrepStmts();
    }

    public boolean getUseTimezone() {
        return xaDataSource.getUseTimezone();
    }

    public boolean getUseUltraDevWorkAround() {
        return xaDataSource.getUseUltraDevWorkAround();
    }

    public boolean getUseUnbufferedInput() {
        return xaDataSource.getUseUnbufferedInput();
    }

    public boolean getUseUnicode() {
        return xaDataSource.getUseUnicode();
    }

    public boolean getUseUsageAdvisor() {
        return xaDataSource.getUseUsageAdvisor();
    }

    public boolean getYearIsDateType() {
        return xaDataSource.getYearIsDateType();
    }

    public String getZeroDateTimeBehavior() {
        return xaDataSource.getZeroDateTimeBehavior();
    }

    public void setAllowLoadLocalInfile(boolean property) {
        xaDataSource.setAllowLoadLocalInfile(property);
    }

    public void setAllowMultiQueries(boolean property) {
        xaDataSource.setAllowMultiQueries(property);
    }

    public void setAllowNanAndInf(boolean flag) {
        xaDataSource.setAllowNanAndInf(flag);
    }

    public void setAllowUrlInLocalInfile(boolean flag) {
        xaDataSource.setAllowUrlInLocalInfile(flag);
    }

    public void setAlwaysSendSetIsolation(boolean flag) {
        xaDataSource.setAlwaysSendSetIsolation(flag);
    }

    public void setAutoDeserialize(boolean flag) {
        xaDataSource.setAutoDeserialize(flag);
    }

    public void setAutoGenerateTestcaseScript(boolean flag) {
        xaDataSource.setAutoGenerateTestcaseScript(flag);
    }

    public void setAutoReconnect(boolean flag) {
        xaDataSource.setAutoReconnect(flag);
    }

    public void setAutoReconnectForConnectionPools(boolean property) {
        xaDataSource.setAutoReconnectForConnectionPools(property);
    }

    public void setAutoReconnectForPools(boolean flag) {
        xaDataSource.setAutoReconnectForPools(flag);
    }

    public void setBlobSendChunkSize(String value) throws SQLException {
        xaDataSource.setBlobSendChunkSize(value);
    }

    public void setCacheCallableStatements(boolean flag) {
        xaDataSource.setCacheCallableStatements(flag);
    }

    public void setCachePreparedStatements(boolean flag) {
        xaDataSource.setCachePreparedStatements(flag);
    }

    public void setCacheResultSetMetadata(boolean property) {
        xaDataSource.setCacheResultSetMetadata(property);
    }

    public void setCacheServerConfiguration(boolean flag) {
        xaDataSource.setCacheServerConfiguration(flag);
    }

    public void setCallableStatementCacheSize(int size) {
        xaDataSource.setCallableStatementCacheSize(size);
    }

    public void setCapitalizeDBMDTypes(boolean property) {
        xaDataSource.setCapitalizeDBMDTypes(property);
    }

    public void setCapitalizeTypeNames(boolean flag) {
        xaDataSource.setCapitalizeTypeNames(flag);
    }

    public void setCharacterEncoding(String encoding) {
        xaDataSource.setCharacterEncoding(encoding);
    }

    public void setCharacterSetResults(String characterSet) {
        xaDataSource.setCharacterSetResults(characterSet);
    }

    public void setClobberStreamingResults(boolean flag) {
        xaDataSource.setClobberStreamingResults(flag);
    }

    public void setClobCharacterEncoding(String encoding) {
        xaDataSource.setClobCharacterEncoding(encoding);
    }

    public void setConnectionCollation(String collation) {
        xaDataSource.setConnectionCollation(collation);
    }

    public void setConnectTimeout(int timeoutMs) {
        xaDataSource.setConnectTimeout(timeoutMs);
    }

    public void setContinueBatchOnError(boolean property) {
        xaDataSource.setContinueBatchOnError(property);
    }

    public void setCreateDatabaseIfNotExist(boolean flag) {
        xaDataSource.setCreateDatabaseIfNotExist(flag);
    }

    public void setDefaultFetchSize(int n) {
        xaDataSource.setDefaultFetchSize(n);
    }

    public void setDetectServerPreparedStmts(boolean property) {
        xaDataSource.setDetectServerPreparedStmts(property);
    }

    public void setDontTrackOpenResources(boolean flag) {
        xaDataSource.setDontTrackOpenResources(flag);
    }

    public void setDumpQueriesOnException(boolean flag) {
        xaDataSource.setDumpQueriesOnException(flag);
    }

    public void setDynamicCalendars(boolean flag) {
        xaDataSource.setDynamicCalendars(flag);
    }

    public void setElideSetAutoCommits(boolean flag) {
        xaDataSource.setElideSetAutoCommits(flag);
    }

    public void setEmptyStringsConvertToZero(boolean flag) {
        xaDataSource.setEmptyStringsConvertToZero(flag);
    }

    public void setEmulateLocators(boolean property) {
        xaDataSource.setEmulateLocators(property);
    }

    public void setEmulateUnsupportedPstmts(boolean flag) {
        xaDataSource.setEmulateUnsupportedPstmts(flag);
    }

    public void setEnablePacketDebug(boolean flag) {
        xaDataSource.setEnablePacketDebug(flag);
    }

    public void setEncoding(String property) {
        xaDataSource.setEncoding(property);
    }

    public void setExplainSlowQueries(boolean flag) {
        xaDataSource.setExplainSlowQueries(flag);
    }

    public void setFailOverReadOnly(boolean flag) {
        xaDataSource.setFailOverReadOnly(flag);
    }

    public void setGatherPerformanceMetrics(boolean flag) {
        xaDataSource.setGatherPerformanceMetrics(flag);
    }

    public void setHoldResultsOpenOverStatementClose(boolean flag) {
        xaDataSource.setHoldResultsOpenOverStatementClose(flag);
    }

    public void setIgnoreNonTxTables(boolean property) {
        xaDataSource.setIgnoreNonTxTables(property);
    }

    public void setInitialTimeout(int property) {
        xaDataSource.setInitialTimeout(property);
    }

    public void setIsInteractiveClient(boolean property) {
        xaDataSource.setIsInteractiveClient(property);
    }

    public void setJdbcCompliantTruncation(boolean flag) {
        xaDataSource.setJdbcCompliantTruncation(flag);
    }

    public void setLocatorFetchBufferSize(String value) throws SQLException {
        xaDataSource.setLocatorFetchBufferSize(value);
    }

    public void setLogSlowQueries(boolean flag) {
        xaDataSource.setLogSlowQueries(flag);
    }

    public void setMaintainTimeStats(boolean flag) {
        xaDataSource.setMaintainTimeStats(flag);
    }

    public void setMaxQuerySizeToLog(int sizeInBytes) {
        xaDataSource.setMaxQuerySizeToLog(sizeInBytes);
    }

    public void setMaxReconnects(int property) {
        xaDataSource.setMaxReconnects(property);
    }

    public void setMaxRows(int property) {
        xaDataSource.setMaxRows(property);
    }

    public void setMetadataCacheSize(int value) {
        xaDataSource.setMetadataCacheSize(value);
    }

    public void setNoDatetimeStringSync(boolean flag) {
        xaDataSource.setNoDatetimeStringSync(flag);
    }

    public void setNullCatalogMeansCurrent(boolean value) {
        xaDataSource.setNullCatalogMeansCurrent(value);
    }

    public void setNullNamePatternMatchesAll(boolean value) {
        xaDataSource.setNullNamePatternMatchesAll(value);
    }

    public void setPacketDebugBufferSize(int size) {
        xaDataSource.setPacketDebugBufferSize(size);
    }

    public void setParanoid(boolean property) {
        xaDataSource.setParanoid(property);
    }

    public void setPedantic(boolean property) {
        xaDataSource.setPedantic(property);
    }

    public void setPreparedStatementCacheSize(int cacheSize) {
        xaDataSource.setPreparedStatementCacheSize(cacheSize);
    }

    public void setPreparedStatementCacheSqlLimit(int cacheSqlLimit) {
        xaDataSource.setPreparedStatementCacheSqlLimit(cacheSqlLimit);
    }

    public void setProfileSql(boolean property) {
        xaDataSource.setProfileSql(property);
    }

    public void setProfileSQL(boolean flag) {
        xaDataSource.setProfileSQL(flag);
    }

    public void setPropertiesTransform(String value) {
        xaDataSource.setPropertiesTransform(value);
    }

    public void setQueriesBeforeRetryMaster(int property) {
        xaDataSource.setQueriesBeforeRetryMaster(property);
    }

    public void setReconnectAtTxEnd(boolean property) {
        xaDataSource.setReconnectAtTxEnd(property);
    }

    public void setRelaxAutoCommit(boolean property) {
        xaDataSource.setRelaxAutoCommit(property);
    }

    public void setReportMetricsIntervalMillis(int millis) {
        xaDataSource.setReportMetricsIntervalMillis(millis);
    }

    public void setRequireSSL(boolean property) {
        xaDataSource.setRequireSSL(property);
    }

    public void setRetainStatementAfterResultSetClose(boolean flag) {
        xaDataSource.setRetainStatementAfterResultSetClose(flag);
    }

    public void setRollbackOnPooledClose(boolean flag) {
        xaDataSource.setRollbackOnPooledClose(flag);
    }

    public void setRoundRobinLoadBalance(boolean flag) {
        xaDataSource.setRoundRobinLoadBalance(flag);
    }

    public void setRunningCTS13(boolean flag) {
        xaDataSource.setRunningCTS13(flag);
    }

    public void setSecondsBeforeRetryMaster(int property) {
        xaDataSource.setSecondsBeforeRetryMaster(property);
    }

    public void setServerTimezone(String property) {
        xaDataSource.setServerTimezone(property);
    }

    public void setSessionVariables(String variables) {
        xaDataSource.setSessionVariables(variables);
    }

    public void setSlowQueryThresholdMillis(int millis) {
        xaDataSource.setSlowQueryThresholdMillis(millis);
    }

    public void setSocketFactoryClassName(String property) {
        xaDataSource.setSocketFactoryClassName(property);
    }

    public void setSocketTimeout(int property) {
        xaDataSource.setSocketTimeout(property);
    }

    public void setStrictFloatingPoint(boolean property) {
        xaDataSource.setStrictFloatingPoint(property);
    }

    public void setStrictUpdates(boolean property) {
        xaDataSource.setStrictUpdates(property);
    }

    public void setTinyInt1isBit(boolean flag) {
        xaDataSource.setTinyInt1isBit(flag);
    }

    public void setTraceProtocol(boolean flag) {
        xaDataSource.setTraceProtocol(flag);
    }

    public void setTransformedBitIsBoolean(boolean flag) {
        xaDataSource.setTransformedBitIsBoolean(flag);
    }

    public void setUseCompression(boolean property) {
        xaDataSource.setUseCompression(property);
    }

    public void setUseFastIntParsing(boolean flag) {
        xaDataSource.setUseFastIntParsing(flag);
    }

    public void setUseHostsInPrivileges(boolean property) {
        xaDataSource.setUseHostsInPrivileges(property);
    }

    public void setUseInformationSchema(boolean flag) {
        xaDataSource.setUseInformationSchema(flag);
    }

    public void setUseLocalSessionState(boolean flag) {
        xaDataSource.setUseLocalSessionState(flag);
    }

    public void setUseOldUTF8Behavior(boolean flag) {
        xaDataSource.setUseOldUTF8Behavior(flag);
    }

    public void setUseOnlyServerErrorMessages(boolean flag) {
        xaDataSource.setUseOnlyServerErrorMessages(flag);
    }

    public void setUseReadAheadInput(boolean flag) {
        xaDataSource.setUseReadAheadInput(flag);
    }

    public void setUseServerPreparedStmts(boolean flag) {
        xaDataSource.setUseServerPreparedStmts(flag);
    }

    public void setUseSqlStateCodes(boolean flag) {
        xaDataSource.setUseSqlStateCodes(flag);
    }

    public void setUseSSL(boolean property) {
        xaDataSource.setUseSSL(property);
    }

    public void setUseStreamLengthsInPrepStmts(boolean property) {
        xaDataSource.setUseStreamLengthsInPrepStmts(property);
    }

    public void setUseTimezone(boolean property) {
        xaDataSource.setUseTimezone(property);
    }

    public void setUseUltraDevWorkAround(boolean property) {
        xaDataSource.setUseUltraDevWorkAround(property);
    }

    public void setUseUnbufferedInput(boolean flag) {
        xaDataSource.setUseUnbufferedInput(flag);
    }

    public void setUseUnicode(boolean flag) {
        xaDataSource.setUseUnicode(flag);
    }

    public void setUseUsageAdvisor(boolean useUsageAdvisorFlag) {
        xaDataSource.setUseUsageAdvisor(useUsageAdvisorFlag);
    }

    public void setYearIsDateType(boolean flag) {
        xaDataSource.setYearIsDateType(flag);
    }

    public void setZeroDateTimeBehavior(String behavior) {
        xaDataSource.setZeroDateTimeBehavior(behavior);
    }

    public boolean useUnbufferedInput() {
        return xaDataSource.useUnbufferedInput();
    }

    public boolean getUseCursorFetch() {
        return xaDataSource.getUseCursorFetch();
    }

    public void setUseCursorFetch(boolean flag) {
        xaDataSource.setUseCursorFetch(flag);
    }

    public boolean getOverrideSupportsIntegrityEnhancementFacility() {
        return xaDataSource.getOverrideSupportsIntegrityEnhancementFacility();
    }

    public void setOverrideSupportsIntegrityEnhancementFacility(boolean flag) {
        xaDataSource.setOverrideSupportsIntegrityEnhancementFacility(flag);
    }

    public boolean getNoTimezoneConversionForTimeType() {
        return xaDataSource.getNoTimezoneConversionForTimeType();
    }

    public void setNoTimezoneConversionForTimeType(boolean flag) {
        xaDataSource.setNoTimezoneConversionForTimeType(flag);
    }

    public boolean getUseJDBCCompliantTimezoneShift() {
        return xaDataSource.getUseJDBCCompliantTimezoneShift();
    }

    public void setUseJDBCCompliantTimezoneShift(boolean flag) {
        xaDataSource.setUseJDBCCompliantTimezoneShift(flag);
    }

    public boolean getAutoClosePStmtStreams() {
        return xaDataSource.getAutoClosePStmtStreams();
    }

    public void setAutoClosePStmtStreams(boolean flag) {
        xaDataSource.setAutoClosePStmtStreams(flag);
    }

    public boolean getProcessEscapeCodesForPrepStmts() {
        return xaDataSource.getProcessEscapeCodesForPrepStmts();
    }

    public void setProcessEscapeCodesForPrepStmts(boolean flag) {
        xaDataSource.setProcessEscapeCodesForPrepStmts(flag);
    }

    public boolean getUseGmtMillisForDatetimes() {
        return xaDataSource.getUseGmtMillisForDatetimes();
    }

    public void setUseGmtMillisForDatetimes(boolean flag) {
        xaDataSource.setUseGmtMillisForDatetimes(flag);
    }

    public boolean getDumpMetadataOnColumnNotFound() {
        return xaDataSource.getDumpMetadataOnColumnNotFound();
    }

    public void setDumpMetadataOnColumnNotFound(boolean flag) {
        xaDataSource.setDumpMetadataOnColumnNotFound(flag);
    }

    public String getResourceId() {
        return xaDataSource.getResourceId();
    }

    public void setResourceId(String resourceId) {
        xaDataSource.setResourceId(resourceId);
    }

    public boolean getRewriteBatchedStatements() {
        return xaDataSource.getRewriteBatchedStatements();
    }

    public void setRewriteBatchedStatements(boolean flag) {
        xaDataSource.setRewriteBatchedStatements(flag);
    }

    public boolean getJdbcCompliantTruncationForReads() {
        return xaDataSource.getJdbcCompliantTruncationForReads();
    }

    public void setJdbcCompliantTruncationForReads(boolean jdbcCompliantTruncationForReads) {
        xaDataSource.setJdbcCompliantTruncationForReads(jdbcCompliantTruncationForReads);
    }

    public boolean getUseJvmCharsetConverters() {
        return xaDataSource.getUseJvmCharsetConverters();
    }

    public void setUseJvmCharsetConverters(boolean flag) {
        xaDataSource.setUseJvmCharsetConverters(flag);
    }

    public boolean getPinGlobalTxToPhysicalConnection() {
        return xaDataSource.getPinGlobalTxToPhysicalConnection();
    }

    public void setPinGlobalTxToPhysicalConnection(boolean flag) {
        xaDataSource.setPinGlobalTxToPhysicalConnection(flag);
    }

    public void setGatherPerfMetrics(boolean flag) {
        xaDataSource.setGatherPerfMetrics(flag);
    }

    public boolean getGatherPerfMetrics() {
        return xaDataSource.getGatherPerfMetrics();
    }

    public void setUltraDevHack(boolean flag) {
        xaDataSource.setUltraDevHack(flag);
    }

    public boolean getUltraDevHack() {
        return xaDataSource.getUltraDevHack();
    }

    public void setInteractiveClient(boolean property) {
        xaDataSource.setInteractiveClient(property);
    }

    public void setSocketFactory(String name) {
        xaDataSource.setSocketFactory(name);
    }

    public String getSocketFactory() {
        return xaDataSource.getSocketFactory();
    }

    public void setUseServerPrepStmts(boolean flag) {
        xaDataSource.setUseServerPrepStmts(flag);
    }

    public boolean getUseServerPrepStmts() {
        return xaDataSource.getUseServerPrepStmts();
    }

    public void setCacheCallableStmts(boolean flag) {
        xaDataSource.setCacheCallableStmts(flag);
    }

    public boolean getCacheCallableStmts() {
        return xaDataSource.getCacheCallableStmts();
    }

    public void setCachePrepStmts(boolean flag) {
        xaDataSource.setCachePrepStmts(flag);
    }

    public boolean getCachePrepStmts() {
        return xaDataSource.getCachePrepStmts();
    }

    public void setCallableStmtCacheSize(int cacheSize) {
        xaDataSource.setCallableStmtCacheSize(cacheSize);
    }

    public int getCallableStmtCacheSize() {
        return xaDataSource.getCallableStmtCacheSize();
    }

    public void setPrepStmtCacheSize(int cacheSize) {
        xaDataSource.setPrepStmtCacheSize(cacheSize);
    }

    public int getPrepStmtCacheSize() {
        return xaDataSource.getPrepStmtCacheSize();
    }

    public void setPrepStmtCacheSqlLimit(int sqlLimit) {
        xaDataSource.setPrepStmtCacheSqlLimit(sqlLimit);
    }

    public int getPrepStmtCacheSqlLimit() {
        return xaDataSource.getPrepStmtCacheSqlLimit();
    }

    public boolean getNoAccessToProcedureBodies() {
        return xaDataSource.getNoAccessToProcedureBodies();
    }

    public void setNoAccessToProcedureBodies(boolean flag) {
        xaDataSource.setNoAccessToProcedureBodies(flag);
    }

    public boolean getUseOldAliasMetadataBehavior() {
        return xaDataSource.getUseOldAliasMetadataBehavior();
    }

    public void setUseOldAliasMetadataBehavior(boolean flag) {
        xaDataSource.setUseOldAliasMetadataBehavior(flag);
    }

    public boolean getUseSSPSCompatibleTimezoneShift() {
        return xaDataSource.getUseSSPSCompatibleTimezoneShift();
    }

    public void setUseSSPSCompatibleTimezoneShift(boolean flag) {
        xaDataSource.setUseSSPSCompatibleTimezoneShift(flag);
    }

    public boolean getTreatUtilDateAsTimestamp() {
        return xaDataSource.getTreatUtilDateAsTimestamp();
    }

    public void setTreatUtilDateAsTimestamp(boolean flag) {
        xaDataSource.setTreatUtilDateAsTimestamp(flag);
    }

    public boolean getUseFastDateParsing() {
        return xaDataSource.getUseFastDateParsing();
    }

    public void setUseFastDateParsing(boolean flag) {
        xaDataSource.setUseFastDateParsing(flag);
    }

    public String getLocalSocketAddress() {
        return xaDataSource.getLocalSocketAddress();
    }

    public void setLocalSocketAddress(String address) {
        xaDataSource.setLocalSocketAddress(address);
    }

    public void setUseConfigs(String configs) {
        xaDataSource.setUseConfigs(configs);
    }

    public String getUseConfigs() {
        return xaDataSource.getUseConfigs();
    }

    public boolean getGenerateSimpleParameterMetadata() {
        return xaDataSource.getGenerateSimpleParameterMetadata();
    }

    public void setGenerateSimpleParameterMetadata(boolean flag) {
        xaDataSource.setGenerateSimpleParameterMetadata(flag);
    }

    public boolean getLogXaCommands() {
        return xaDataSource.getLogXaCommands();
    }

    public void setLogXaCommands(boolean flag) {
        xaDataSource.setLogXaCommands(flag);
    }

    public int getResultSetSizeThreshold() {
        return xaDataSource.getResultSetSizeThreshold();
    }

    public void setResultSetSizeThreshold(int threshold) {
        xaDataSource.setResultSetSizeThreshold(threshold);
    }
    /**
     * Equality is defined in terms of the serverName, portNumber and databaseName properties
     */
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof XAMCF) {
            MysqlXADataSource other = ((XAMCF) obj).xaDataSource;
            return equals(xaDataSource.getServerName(), other.getServerName()) &&
                    xaDataSource.getPortNumber() == other.getPortNumber() &&
                    equals(xaDataSource.getDatabaseName(), other.getDatabaseName());
        } else {
            return false;
        }
    }

    private static boolean equals(String a, String b) {
        return a == b || a != null && a.equals(b);
    }

    public int hashCode() {
        return hashCode(xaDataSource.getServerName()) ^ xaDataSource.getPortNumber() ^ hashCode(xaDataSource.getDatabaseName());
    }

    private static int hashCode(String s) {
        return s == null ? 0 : s.hashCode();
    }

    public String toString() {
        return "XAMCF[" + getDatabaseName() + ']';
    }
}
